import { graphql } from "@/gql";
import { EventFragment } from "@/gql/graphql";
import { getClient } from "@/app/client";
import { Blocks } from "@/components/blocks/Blocks";
import Image from "@/components/general/Image";
import { EventHeader } from "@/components/events/EventHeader";
import { DateList } from "@/components/events/DateList";

export async function generateStaticParams() {
  const allEventSlugsQuery = graphql(`
    query allEventSlugs {
      pages(contentType: "events.EventPage") {
        id
        slug
      }
    }
  `);
  const { data, error } = await getClient().query(allEventSlugsQuery, {});

  if (data === undefined || error) {
    throw new Error("failed to generate static params");
  }

  return data?.pages.map((page: any) => ({
    slug: page.slug,
  }));
}

export default async function Page({ params }: { params: { slug: string } }) {
  const eventBySlugQuery = graphql(`
    query eventBySlug($slug: String!) {
      event: page(contentType: "events.EventPage", slug: $slug) {
        ... on EventPage {
          ...Event
        }
      }
    }
  `);


  const { data, error } = await getClient().query(eventBySlugQuery, {
    slug: params.slug,
  });

  const event = (data?.event ?? {}) as EventFragment;

  return (
    <main className="site-main" id="main">
      <EventHeader event={event} />
      <section className="page-content">
        <DateList />
        <Blocks blocks={event.body} />
      </section>
    </main>
  );
}
